==> sympa-6.0.1p0.tgz: libdata/perl5/site_perl/Sympa/Sympa/Constants.pm <==
# Sympa::Constants.pm - This module contains all installation-related variables
# RCS Identication ; $Revision: 5768 $ ; $Date: 2009-05-21 16:23:23 +0200 (jeu. 21 mai 2009) $ 
#
# Sympa - SYsteme de Multi-Postage Automatique
# Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
# Copyright (c) 1997,1998, 1999 Institut Pasteur & Christophe Wolfhugel
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

package Sympa::Constants;
use strict;

use Exporter;
our @ISA = qw(Exporter);


use constant VERSION => '6.0.1';
use constant USER    => '_sympa';
use constant GROUP   => '_sympa';

use constant CONFIG           => '/etc/sympa.conf';
use constant WWSCONFIG        => '/etc/wwsympa.conf';
use constant SENDMAIL_ALIASES => '/var/sympa/sympa_aliases';

use constant PIDDIR     => '/var/run/sympa';
use constant EXPLDIR    => '/var/sympa/list_data';
use constant SPOOLDIR   => '/var/spool/sympa';
use constant SYSCONFDIR => '/etc';
use constant LOCALEDIR  => '/usr/local/share/locale';
use constant LIBEXECDIR => '/usr/local/libexec/sympa';
use constant SBINDIR    => '/usr/local/sbin';
use constant SCRIPTDIR  => '/usr/local/bin';
use constant MODULEDIR  => '/usr/local/libdata/perl5/site_perl/Sympa';
use constant DEFAULTDIR => '/usr/local/share/sympa';
use constant STATICDIR  => '/var/sympa/static';
use constant ARCDIR    => '/var/sympa/archives';
use constant BOUNCEDIR  => '/var/sympa/bounces';

1;

==> sympa-6.1.3p0.tgz: libdata/perl5/site_perl/Sympa/Sympa/Constants.pm <==
# Sympa::Constants.pm - This module contains all installation-related variables
# RCS Identication ; $Revision: 5768 $ ; $Date: 2009-05-21 16:23:23 +0200 (jeu. 21 mai 2009) $ 
#
# Sympa - SYsteme de Multi-Postage Automatique
# Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
# Copyright (c) 1997,1998, 1999 Institut Pasteur & Christophe Wolfhugel
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

package Sympa::Constants;
use strict;

use Exporter;
our @ISA = qw(Exporter);


use constant VERSION => '6.1.3';
use constant USER    => '_sympa';
use constant GROUP   => '_sympa';

use constant CONFIG           => '/var/sympa/etc//sympa.conf';
use constant WWSCONFIG        => '/var/sympa/etc//wwsympa.conf';
use constant SENDMAIL_ALIASES => '/var/sympa/sympa_aliases';

use constant PIDDIR     => '/var/run/sympa';
use constant EXPLDIR    => '/var/sympa/list_data';
use constant SPOOLDIR   => '/var/spool/sympa';
use constant SYSCONFDIR => '/etc';
use constant LOCALEDIR  => '/usr/local/share/locale';
use constant LIBEXECDIR => '/usr/local/libexec/sympa';
use constant SBINDIR    => '/usr/local/sbin';
use constant SCRIPTDIR  => '/usr/local/bin';
use constant MODULEDIR  => '/usr/local/libdata/perl5/site_perl/Sympa';
use constant DEFAULTDIR => '/usr/local/share/sympa';
use constant STATICDIR  => '/var/www/sympa';
use constant ARCDIR    => '/var/sympa/archives';
use constant BOUNCEDIR  => '/var/sympa/bounces';

1;
